/*
 * IrcBG-HybServ TS Services, Copyright (C) 1999-2000 Nedelcho Stanev
 * This program comes with absolutely NO WARRANTY
 *
 * Should you choose to use and/or modify this source code, please
 * do so under the terms of the GNU General Public License under which
 * this program is distributed.
 *
 * $Id: messages.c,v 1.1 2000/10/07 16:33:55 decho Exp $
 */

#include <stdio.h>
#include <stdarg.h>
#include <unistd.h>
#include <string.h>
#include <assert.h>

#include "client.h"
#include "conf.h"
#include "config.h"
#include "data.h"
#include "dcc.h"
#include "defs.h"
#include "hash.h"
#include "hybdefs.h"
#include "match.h"
#include "misc.h"
#include "messages.h"


struct Language languages[] = {
  { LANG_UK, "English" },
  { LANG_BG, "Bulgarian (english letters)" },
  { LANG_BW, "Bulgarian CP1251" },
  { LANG_UN, "UNDEFINED" },
  { 0, NULL }
};

// Language specific messages
struct NLSMessage arr_messages[] = {
  { MSG_WELCOME 	, LANG_UK, "Wellcome" },
  { MSG_WELCOME 	, LANG_BG, "Zdraveite" },
  { MSG_WELCOME 	, LANG_BW, "" },

  { MSG_ACCSDND 	, LANG_UK, "Access denied" },
  { MSG_ACCSDND 	, LANG_BG, "Dostapat otakazan" },
  { MSG_ACCSDND 	, LANG_BW, " " },

  { MSG_DISABLED	, LANG_UK, "Services are currently \002disabled\002" },
  { MSG_DISABLED        , LANG_BG, "Services v momenta sa \002izkluchen\002" },
  { MSG_DISABLED        , LANG_BW, "Services    \002\002" },

  { MSG_AMBIGOUS	, LANG_UK, "Ambiguous" },
  { MSG_AMBIGOUS        , LANG_BG, "Lipswashta" },
  { MSG_AMBIGOUS        , LANG_BW, "" },

  { MSG_UNKNOWN		, LANG_UK, "Unknown" },
  { MSG_UNKNOWN         , LANG_BG, "Nepoznata" },
  { MSG_UNKNOWN         , LANG_BW, "" },

  { MSG_COMMAND		, LANG_UK, "command" },
  { MSG_COMMAND         , LANG_BG, "komanda" },
  { MSG_COMMAND         , LANG_BW, "" },

  { MSG_FORBNICK        , LANG_UK, "Cannot execute commands for forbidden nicknames" },
  { MSG_FORBNICK        , LANG_BG, "Ne moga da izpalnjavam komandi za zabraneni nickove" },
  { MSG_FORBNICK        , LANG_BW, "       " },

  { MSG_REGFRST		, LANG_UK, "You must register your nick with \002%s\002 first" },
  { MSG_REGFRST		, LANG_BG, "Parvo trqbva de se registrirate s pomoshta na \002%s\002" },
  { MSG_REGFRST		, LANG_BW, "        \002%s\002" },

  { MSG_REGINTRO1	, LANG_UK, "Type: \002/msg %s REGISTER <password>\002 to register your nickname" },
  { MSG_REGINTRO1	, LANG_BG, "Napishete \002/msg %s REGISTER <parola>\002 za da registrirate Vashia nick" },
  { MSG_REGINTRO1	, LANG_BW, " \002/msg %s REGISTER <>\002     nick" },

  { MSG_IDENTIFY1       , LANG_UK, "Password identification is required for [\002%s\002]" },
  { MSG_IDENTIFY1	, LANG_BG, "Neobhodimo e da ste se identificirali za ispalnenie na [\002%s\002]" },
  { MSG_IDENTIFY1	, LANG_BW, "         [\002%s\002]" },

  { MSG_IDENTIFY2	, LANG_UK, "Type \002/msg %s IDENTIFY <password>\002 and retry" },
  { MSG_IDENTIFY2       , LANG_BG, "Napishete \002/msg %s IDENTIFY <parola>\002 i opitatite otnovo" },
  { MSG_IDENTIFY2       , LANG_BW, " \002/msg %s IDENTIFY <>\002   " },

  { MSG_NICKNOTUSE1     , LANG_UK, "This nickname may not be used.  Please choose another." },
  { MSG_NICKNOTUSE1     , LANG_BG, "Tozi nick ne moje da se ispolzva. Molja,  izberete drug nick." },	
  { MSG_NICKNOTUSE1     , LANG_BW, " nick     .  ,   nick." },

  { MSG_NICKNOTUSE2     , LANG_UK, "If you do not change within one minute, you will be disconnected" },
  { MSG_NICKNOTUSE2     , LANG_BG, "Ako ne go smenite v ramkite na 1 minuta shte badete otkachen ot mrejata" },
  { MSG_NICKNOTUSE2     , LANG_BW, "       1      " },

  { MSG_IDENTIFY3	, LANG_UK, "This nickname is owned by someone else" },
  { MSG_IDENTIFY3       , LANG_BG, "Tozi nick se ispolzva veche ot njakoi" },
  { MSG_IDENTIFY3       , LANG_BW, " nick     " },

  { MSG_IDENTIFY4       , LANG_UK, "If this is your nickname, type /msg %s \002IDENTIFY\002 <password>" },
  { MSG_IDENTIFY4       , LANG_BG, "Ako tova e Vashiat nick, napishete /msg %s \002IDENTIFY\002 <parola>" },
  { MSG_IDENTIFY4       , LANG_BW, "    nick ,  /msg %s \002IDENTIFY\002 <>" },

  { MSG_IDENTIFY5       , LANG_UK, "If you do not \002IDENTIFY\002 within one minute, you will be disconnected" },
  { MSG_IDENTIFY5       , LANG_BG, "Ako ne se \002IDENTIFICIRATE\002 do 1 minuta shte badete otkacheni ot mrejata" },
  { MSG_IDENTIFY5       , LANG_BW, "   \002\002  1      " }, 	
 
  { MSG_NEWMEMOS        , LANG_UK, "You have \002%d\002 new memo" },
  { MSG_NEWMEMOS        , LANG_BG, "Vie imate \002%d\002 novi syobshteniq" },
  { MSG_NEWMEMOS        , LANG_BW, "  \002%d\002  " }, 

  { MSG_LISTMEMOS       , LANG_UK, "Type \002/msg %s LIST\002 to view them" },
  { MSG_LISTMEMOS       , LANG_BG, "Napishete \002/msg %s LIST\002 za da gi vidite" },
  { MSG_LISTMEMOS       , LANG_BW, " \002/msg %s LIST\002    " },

  { MSG_IRCOPFLAG1	, LANG_UK, "You have not set the IRC Operator flag for your nickname" },  
  { MSG_IRCOPFLAG1      , LANG_BG, "Vie ne ste zadali flaga za IRC Operator za Vashiat nick vse oshte" },
  { MSG_IRCOPFLAG1      , LANG_BW, "      IRC    nick  " },
  
  { MSG_IRCOPFLAG2 	, LANG_UK, "Please type \002/msg %s SET OPER ON\002 so your nickname does not expire" },
  { MSG_IRCOPFLAG2      , LANG_BG, "Napishete \002/msg %s SET OPER ON\002 za da ne izticha registraciata na Vashiat nick" },
  { MSG_IRCOPFLAG2      , LANG_BW, " \002/msg %s SET OPER ON\002        nick" },
 
  { MSG_NOHELPAVAIL	, LANG_UK, "No help available on \002%s\002" },
  { MSG_NOHELPAVAIL	, LANG_BG, "V momenta lipsva informacia za \002%s\002" },
  { MSG_NOHELPAVAIL	, LANG_BW, "     \002%s\002" },

  { MSG_REGISTER1	, LANG_UK, "Syntax: \002REGISTER\002 <password> <email>" },
  { MSG_REGISTER1	, LANG_BG, "Sintaksis: \002REGISTER\002 <parola> <email>" },
  { MSG_REGISTER1 	, LANG_BW, ": \002REGISTER\002 <> <email>" },

  { MSG_MORE_INFO	, LANG_UK, "Type: \002/msg %s HELP %s\002 for more information" },
  { MSG_MORE_INFO	, LANG_BG, "Napishete: \002/msg %s HELP %s\002 za poweche informacia" },
  { MSG_MORE_INFO	, LANG_BW, ": \002/msg %s HELP %s\002   " },

  { MSG_ALR_REGISTERED	, LANG_UK, "The nickname [\002%s\002] is already registered" },
  { MSG_ALR_REGISTERED	, LANG_BG, "Tozi nick [\002%s\002] veche e registriran" },
  { MSG_ALR_REGISTERED 	, LANG_BW, " nick [\002%s\002]   " },

  { MSG_REG_WAIT	, LANG_UK, "Please wait %ld seconds before using REGISTER again" },
  { MSG_REG_WAIT	, LANG_BG, "Molja izchakaite %ld sekundi predi da ispolzvate REGISTER otnovo" },
  { MSG_REG_WAIT	, LANG_BW, "  %ld     REGISTER " },

  { MSG_REG_FAILED	, LANG_UK, "Register failed" },
  { MSG_REG_FAILED 	, LANG_BG, "Neuspeshna registracia" },
  { MSG_REG_FAILED	, LANG_BW, " " },

  { MSG_REGISTER2     	, LANG_UK, "Your nickname is now registered under the hostmask [\002%s\002]\n" },
  { MSG_REGISTER2	, LANG_BG, "Vashiat nick e registriran sas slednata hostmaska [\002%s\002]\n" },
  { MSG_REGISTER2	, LANG_BW, " nick      [\002%s\002]\n" },

  { MSG_REGISTER3	, LANG_UK, "Your password is [\002%s\002] - Remember this for later use" },
  { MSG_REGISTER3	, LANG_BG, "Vashata parola e [\002%s\002] - Molja, zapomnete ja za po-natatushna upotreba" },
  { MSG_REGISTER3	, LANG_BW, "   [\002%s\002] - ,    - " },

  { MSG_REGISTER4	, LANG_UK, "Your registration email is  [\002%s\002]" },
  { MSG_REGISTER4	, LANG_BG, "Email-a s koito e registriran nick-at Vi e [\002%s\002]" },
  { MSG_REGISTER4	, LANG_BW, "Email-     nick-    [\002%s\002]" },

  { MSG_NOTREGISTERED	, LANG_UK, "The nickname [\002%s\002] is not registered" },
  { MSG_NOTREGISTERED	, LANG_BG, "Nickat [\002%s\002] ne e registriran" },
  { MSG_NOTREGISTERED	, LANG_BW, "Nick- [\002%s\002]   " },

  { MSG_DROP_SYNTAX	, LANG_UK, "Syntax: \002DROP\002 [password]" },
  { MSG_DROP_SYNTAX	, LANG_BG, "Sintaksis: \002DROP\002 [parola]" },
  { MSG_DROP_SYNTAX	, LANG_BW, ": \002DROP\002 []" },

  { MSG_WRONG_PASS	, LANG_UK, "Password Incorrect" },
  { MSG_WRONG_PASS	, LANG_BG, "Greshna parola" },
  { MSG_WRONG_PASS	, LANG_BW, " " },

  { MSG_NICK_DROPPED	, LANG_UK, "The nickname [\002%s\002] has been dropped" },
  { MSG_NICK_DROPPED    , LANG_BG, "Nick-at [\002%s\002] e premahnat ot bazata danni s registriranite nickove" },
  { MSG_NICK_DROPPED	, LANG_BW, "Nick- [\002%s\002]        nick-" }, 

  { MSG_IDENT_SINTAX	, LANG_UK, "Syntax: \002IDENTIFY\002 <password>" },
  { MSG_IDENT_SINTAX	, LANG_BG, "Sintaksis: \002IDENTIFY\002 <parola>" },
  { MSG_IDENT_SINTAX	, LANG_BW, ": \002IDENTIFY\002 <>" },

  { MSG_ALR_IDENTIFYED	, LANG_UK, "You have already identified" },
  { MSG_ALR_IDENTIFYED	, LANG_BG, "Vie veche ste se identificirali" },
  { MSG_ALR_IDENTIFYED	, LANG_BW, "    " },

  { MSG_IDENTIFY_OK	, LANG_UK, "Password accepted - you are now recognized" },
  { MSG_IDENTIFY_OK     , LANG_BG, "Parolata e prieta,veche ste identificiran" },
  { MSG_IDENTIFY_OK     , LANG_BW, "  ,   " },

  { MSG_HOST_ADDED	, LANG_UK, "Added hostmask [\002%s\002] to the list of your known hosts" },
  { MSG_HOST_ADDED      , LANG_BG, "Hostmaskata [\002%s\002] e dobavena kam spisaka s Vashite hostove" },
  { MSG_HOST_ADDED      , LANG_BW, " [\002%s\002]       " },

  { MSG_RECV_SYNTAX	, LANG_UK, "Syntax: \002RECOVER <nick> [password]\002" },
  { MSG_RECV_SYNTAX	, LANG_BG, "Sintaksis: \002RECOVER <nick> [parola]\002" },
  { MSG_RECV_SYNTAX	, LANG_BW, ": \002RECOVER <nick> []\002" },

  { MSG_ALR_RECV	, LANG_UK, "The nickname [\002%s\002] has already been recovered" },
  { MSG_ALR_RECV	, LANG_BG, "Nick-at [\002%s\002] veche e bil osvoboden" },
  { MSG_ALR_RECV	, LANG_BW, "Nick- [\002%s\002]    " },

  { MSG_NOTONLINE	, LANG_UK, "[\002%s\002] is not currently online" },
  { MSG_NOTONLINE	, LANG_BG, "[\002%s\002] v momenta ne e na mrejata" },
  { MSG_NOTONLINE	, LANG_BW, "[\002%s\002]      " },

  { MSG_RECOVERED	, LANG_UK, "The nickname [\002%s\002] has been recovered" },
  { MSG_RECOVERED	, LANG_BG, "Nick-at [\002%s\002] e osvoboden" },
  { MSG_RECOVERED	, LANG_BW, "Nick- [\002%s\002]  " },

  { MSG_NEEDRELEASE	, LANG_UK, "Type: \002/msg %s RELEASE %s\002 to release the nickname before the timeout" },
  { MSG_NEEDRELEASE	, LANG_BG, "Napishete: \002/msg %s RELEASE %s\002 za da bade premahnat nicka ot mrejata predi da izteche taimautat" },
  { MSG_NEEDRELEASE	, LANG_BW, ": \002/msg %s RELEASE %s\002     nick-      " },

  { MSG_REL_SYNTAX	, LANG_UK, "Syntax: \002RELEASE <nickname> [password]\002" },
  { MSG_REL_SYNTAX      , LANG_BG, "Sintaksis: \002RELEASE <nick> [parola]\002" },
  { MSG_REL_SYNTAX      , LANG_BW, ": \002RELEASE <nick> []\002" },

  { MSG_CANT_ENFORCE	, LANG_UK, "The nickname [\002%s\002] is not being enforced" },
  { MSG_CANT_ENFORCE    , LANG_BG, "Nick-at [\002%s\002] ne moje da byde premahnat ot mrejata" },
  { MSG_CANT_ENFORCE    , LANG_BW, "Nick- [\002%s\002]       " },

  { MSG_RELEASED	, LANG_UK, "The nickname [\002%s\002] has been released" },
  { MSG_RELEASED        , LANG_BG, "Nick-at [\002%s\002] e svoboden za ispolzvane" },
  { MSG_RELEASED        , LANG_BW, "Nick- [\002%s\002]    " },

  { MSG_GHOST_SYNTAX	, LANG_UK, "Syntax: \002GHOST <nickname> [password]\002" },
  { MSG_GHOST_SYNTAX	, LANG_BG, "Sitnaksis: \002GHOST <nick> [parola]\002" },
  { MSG_GHOST_SYNTAX	, LANG_BW, ": \002GHOST <nick> []\002" },

  { MSG_KILLED		, LANG_UK, "[\002%s\002] has been killed" },
  { MSG_KILLED		, LANG_BG, "[\002%s\002] e ubit" },
  { MSG_KILLED		, LANG_BW, "[\002%s\002]  " }, 
 
  { MSG_ACCESS_SYNTAX	, LANG_UK, "Syntax: \002ACCESS {ADD|DEL|LIST} [mask]\002" },
  { MSG_ACCESS_SYNTAX   , LANG_BG, "Sintaksis: \002ACCESS {ADD|DEL|LIST} [maska]\002" },
  { MSG_ACCESS_SYNTAX   , LANG_BW, ": \002ACCESS {ADD|DEL|LIST} []\002" },

  { MSG_UNKN_SWITCH	, LANG_UK, "%s switch [\002%s\002]" },
  { MSG_UNKN_SWITCH     , LANG_BG, "%s podkomanda [\002%s\002]" },
  { MSG_UNKN_SWITCH     , LANG_BW, "%s  [\002%s\002]" },

  { MSG_ACCADD_SYNTAX1	, LANG_UK, "Syntax: \002ACCESS <nickname> ADD <mask>\002" },
  { MSG_ACCADD_SYNTAX1  , LANG_BG, "Sintaksis: \002ACCESS <nick> ADD <maska>\002" },
  { MSG_ACCADD_SYNTAX1  , LANG_BW, ": \002ACCESS <nick> ADD <>\002" },

  { MSG_ACCADD_SYNTAX2  , LANG_UK, "Syntax: \002ACCESS ADD <mask>\002" },
  { MSG_ACCADD_SYNTAX2  , LANG_BG, "Sintaksis: \002ACCESS ADD <maska>\002" },
  { MSG_ACCADD_SYNTAX2  , LANG_BW, ": \002ACCESS ADD <>\002" },

  { MSG_LONGHOSTMASK	, LANG_UK, "Too long hostmask!" },
  { MSG_LONGHOSTMASK    , LANG_BG, "Prekaleno dalga hostmaska!" },
  { MSG_LONGHOSTMASK    , LANG_BW, "  " },
 
  { MSG_INVMASK		, LANG_UK, "Invalid hostmask" },
  { MSG_INVMASK         , LANG_BG, "Nevalidna hostmaska" },
  { MSG_INVMASK         , LANG_BW, " " },

  { MSG_INVMASK2	, LANG_UK, "The hostmask [\002%s\002] is invalid" },
  { MSG_INVMASK2	, LANG_BG, "Hostmaskata [\002%s\002] ne e validna" },
  { MSG_INVMASK2	, LANG_BW, " [\002%s\002]   " },

  { MSG_MASKMATCH1	, LANG_UK, "[\002%s\002] matches a hostmask already on the Access List for [%s]" },
  { MSG_MASKMATCH1      , LANG_BG, "[\002%s\002] savpada s hostmaska kojqto veche ja ima v access lista za [%s]" },
  { MSG_MASKMATCH1      , LANG_BW, "[\002%s\002]         access list-a  [%s]" },
 
  { MSG_MASKMATCH2      , LANG_UK, "[\002%s\002] matches a hostmask already on your Access List" },
  { MSG_MASKMATCH2      , LANG_BG, "[\002%s\002] veche ja ima vav Vashiat access list" },
  { MSG_MASKMATCH2      , LANG_BW, "[\002%s\002]      access list" },

  { MSG_MASKADDED1	, LANG_UK, "[\002%s\002] has been added to the Access List for [%s]" },
  { MSG_MASKADDED1	, LANG_BG, "[\002%s\002] e dobavena v access-list-a za  [%s]" },
  { MSG_MASKADDED1	, LANG_BW, "[\002%s\002]    access-list-   [%s]" },

  { MSG_MASKADDED2      , LANG_UK, "[\002%s\002] added to your Access List" },
  { MSG_MASKADDED2      , LANG_BG, "[\002%s\002] e dobavena vav Vashiat access-list" },
  { MSG_MASKADDED2      , LANG_BW, "[\002%s\002]     access-list" },

  { MSG_ACCDEL_SYNTAX1	, LANG_UK, "Syntax: \002ACCESS <nickname> DEL <mask>\002" },
  { MSG_ACCDEL_SYNTAX1  , LANG_BG, "Sintaksis: \002ACCESS <nick> DEL <maska>\002" },
  { MSG_ACCDEL_SYNTAX1  , LANG_BW, ": \002ACCESS <nick> DEL <>\002" },

  { MSG_ACCDEL_SYNTAX2	, LANG_UK, "Syntax: \002ACCESS DEL <mask>\002" },
  { MSG_ACCDEL_SYNTAX2  , LANG_BG, "Sintaksis: \002ACCESS DEL <maska>\002" },
  { MSG_ACCDEL_SYNTAX2  , LANG_BW, ": \002ACCESS DEL <>\002" },

  { MSG_HOST_DELETED1 	, LANG_UK, "[\002%s\002] removed from the Access List for [%s]" },
  { MSG_HOST_DELETED1   , LANG_BG, "[\002%s\002] e premahnat ot access-lista za [%s]" },
  { MSG_HOST_DELETED1   , LANG_BW, "[\002%s\002]    access-lista  [%s]" },

  { MSG_HOST_DELETED2   , LANG_UK, "[\002%s\002] removed from your Access List" },
  { MSG_HOST_DELETED2   , LANG_BG, "[\002%s\002] e premahnat ot Vashiat access-list" },
  { MSG_HOST_DELETED2   , LANG_BW, "[\002%s\002]     access-list" },

  { MSG_HOST_NFOUND1	, LANG_UK, "[\002%s\002] was not found on the Acces List for [%s]" },
  { MSG_HOST_NFOUND1    , LANG_BG, "[\002%s\002] ne e nameren v access-lista za [%s]" },
  { MSG_HOST_NFOUND1    , LANG_BW, "[\002%s\002]     access-lista  [%s]" },

  { MSG_HOST_NFOUND2    , LANG_UK, "[\002%s\002] was not found on your Access List" },
  { MSG_HOST_NFOUND2    , LANG_BG, "[\002%s\002] ne e nameren vav Vashiat access-list" },
  { MSG_HOST_NFOUND2    , LANG_BW, "[\002%s\002]      access-list" },

  { MSG_ACCLIST_LOGO	, LANG_UK, "-- Access List for [\002%s\002] --" },
  { MSG_ACCLIST_LOGO    , LANG_BG, "-- Access List za [\002%s\002] --" },
  { MSG_ACCLIST_LOGO    , LANG_BW, "-- Access List  [\002%s\002] --" },

  { MSG_ACCLIST_LOGO_END, LANG_UK, "-- End of list --" },
  { MSG_ACCLIST_LOGO_END, LANG_BG, "-- Kraj na spisaka --" },
  { MSG_ACCLIST_LOGO_END, LANG_BW, "--    --" },

  { MSG_SET_SYNTAX	, LANG_UK, "Syntax: \002SET <option> [parameter]\002" },
  { MSG_SET_SYNTAX      , LANG_BG, "Sintaksis: \002SET <opcia> [parametar]\002" },
  { MSG_SET_SYNTAX      , LANG_BW, ": \002SET <> []\002" },


  { 0, 0, NULL }
};

